@@ -51,6 +51,12 @@ print.restriktor <- function(x, digits = max(3, getOption("digits") - 2), ...) {
           quote = FALSE)
   } else {
     cat("No coefficients\n")
-  }   
+  }
+  cat("\n")
+  
+  if (inherits(x, "conRLM")) {
+    robWeights(x$wgt)
+  }
+  
   invisible(x)
 }
